==> qtjambi-opengl-debuginfo-macos-6.6.0.jar: sources/QtJambiOpenGL/QOpenGLVertexArrayObject_Binder_shell.cpp <==
#include <QtCore/QtGlobal>
#include <QtOpenGL/qopenglvertexarrayobject.h>
#include <QtCore/QVariant>

#include <QtJambi/QtJambiAPI>
#include <QtJambi/RegistryAPI>
#include <QtJambi/Cast>

void deleter_QOpenGLVertexArrayObject_Binder(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QOpenGLVertexArrayObject::Binder")
    QOpenGLVertexArrayObject::Binder *_ptr = reinterpret_cast<QOpenGLVertexArrayObject::Binder *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

// emitting (writeConstructors)
// new Binder(QOpenGLVertexArrayObject*)
void __qt_construct_QOpenGLVertexArrayObject_Binder_0(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct Binder(QOpenGLVertexArrayObject*)")
    jobject v0 = __java_arguments[0].l;
    QOpenGLVertexArrayObject* __qt_v0 = qtjambi_cast<QOpenGLVertexArrayObject* >(__jni_env, v0);
    QOpenGLVertexArrayObject::Binder *__qt_this = new(__qtjambi_ptr) QOpenGLVertexArrayObject::Binder(__qt_v0);
    Q_UNUSED(__jni_object)
    Q_UNUSED(__qt_this)
}

// destruct QOpenGLVertexArrayObject::Binder
void __qt_destruct_QOpenGLVertexArrayObject_Binder(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QOpenGLVertexArrayObject::Binder")
    reinterpret_cast<QOpenGLVertexArrayObject::Binder*>(ptr)->~Binder();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// QOpenGLVertexArrayObject::Binder::Binder(QOpenGLVertexArrayObject*)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_opengl_QOpenGLVertexArrayObject_00024Binder_initialize_1native__Lio_qt_opengl_QOpenGLVertexArrayObject_00024Binder_2Lio_qt_opengl_QOpenGLVertexArrayObject_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object,
 jobject v0)
{
    QTJAMBI_NATIVE_METHOD_CALL("QOpenGLVertexArrayObject::Binder::Binder(QOpenGLVertexArrayObject*)")
    QTJAMBI_TRY {
        jvalue arguments;
        arguments.l = v0;
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QOpenGLVertexArrayObject_Binder_0, sizeof(QOpenGLVertexArrayObject::Binder), typeid(QOpenGLVertexArrayObject::Binder), false, &deleter_QOpenGLVertexArrayObject_Binder, &arguments);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QOpenGLVertexArrayObject::Binder::rebind()
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_opengl_QOpenGLVertexArrayObject_00024Binder_rebind_1native__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
        QOpenGLVertexArrayObject::Binder *__qt_this = QtJambiAPI::objectFromNativeId<QOpenGLVertexArrayObject::Binder>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QOpenGLVertexArrayObject::Binder::rebind()", __qt_this)
        __qt_this->rebind();
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QOpenGLVertexArrayObject::Binder::release()
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_opengl_QOpenGLVertexArrayObject_00024Binder_release_1native__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
        QOpenGLVertexArrayObject::Binder *__qt_this = QtJambiAPI::objectFromNativeId<QOpenGLVertexArrayObject::Binder>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QOpenGLVertexArrayObject::Binder::release()", __qt_this)
        __qt_this->release();
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// emitting (writeJavaLangObjectOverrideFunctions)

void initialize_meta_info_QOpenGLVertexArrayObject_Binder(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerObjectTypeInfo<QOpenGLVertexArrayObject::Binder>("QOpenGLVertexArrayObject::Binder", "io/qt/opengl/QOpenGLVertexArrayObject$Binder");
// BEGIN: function table
    registerConstructorInfos(typeId, &__qt_destruct_QOpenGLVertexArrayObject_Binder, {
        ConstructorInfo(&__qt_construct_QOpenGLVertexArrayObject_Binder_0, "Lio/qt/opengl/QOpenGLVertexArrayObject;")
    });
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_QOpenGLVertexArrayObject_Binder);
// END: type registration

// BEGIN: polymorphic ids
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags
}

==> qtjambi-opengl-debuginfo-macos-6.8.4.jar: sources/QtJambiOpenGL/QOpenGLVertexArrayObject_Binder_shell.cpp <==
#include <QtCore/QtGlobal>
#include <QtOpenGL/qopenglvertexarrayobject.h>
#include <QtCore/QVariant>

#include <QtJambi/QtJambiAPI>
#include <QtJambi/RegistryAPI>
#include <QtJambi/Cast>

void deleter_QOpenGLVertexArrayObject_Binder(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QOpenGLVertexArrayObject::Binder")
    QOpenGLVertexArrayObject::Binder *_ptr = reinterpret_cast<QOpenGLVertexArrayObject::Binder *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

// emitting (writeConstructors)
// new Binder(QOpenGLVertexArrayObject*)
void __qt_construct_QOpenGLVertexArrayObject_Binder_QOpenGLVertexArrayObject_ptr(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool, bool, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct Binder(QOpenGLVertexArrayObject*)")
    jobject v0 = __java_arguments[0].l;
    QOpenGLVertexArrayObject* __qt_v0 = qtjambi_cast<QOpenGLVertexArrayObject*>(__jni_env, v0);
    QOpenGLVertexArrayObject::Binder *__qt_this = new(__qtjambi_ptr) QOpenGLVertexArrayObject::Binder(__qt_v0);
    Q_UNUSED(__qt_this)
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
}

// QOpenGLVertexArrayObject::Binder::Binder(QOpenGLVertexArrayObject*)
extern "C" JNIEXPORT void JNICALL Java_io_qt_opengl_QOpenGLVertexArrayObject_00024Binder_initialize_1native__Lio_qt_opengl_QOpenGLVertexArrayObject_00024Binder_2Lio_qt_opengl_QOpenGLVertexArrayObject_2
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object,
 jobject v0)
{
    QTJAMBI_NATIVE_METHOD_CALL("QOpenGLVertexArrayObject::Binder::Binder(QOpenGLVertexArrayObject*)")
    QTJAMBI_TRY {
        jvalue arguments;
        arguments.l = v0;
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QOpenGLVertexArrayObject_Binder_QOpenGLVertexArrayObject_ptr, sizeof(QOpenGLVertexArrayObject::Binder), typeid(QOpenGLVertexArrayObject::Binder), 0, false, &deleter_QOpenGLVertexArrayObject_Binder, &arguments);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// destruct QOpenGLVertexArrayObject::Binder
void __qt_destruct_QOpenGLVertexArrayObject_Binder(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QOpenGLVertexArrayObject::Binder")
    reinterpret_cast<QOpenGLVertexArrayObject::Binder*>(ptr)->~Binder();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// QOpenGLVertexArrayObject::Binder::rebind()
extern "C" JNIEXPORT void JNICALL Java_io_qt_opengl_QOpenGLVertexArrayObject_00024Binder_rebind_1native__J
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
        QOpenGLVertexArrayObject::Binder *__qt_this = QtJambiAPI::objectFromNativeId<QOpenGLVertexArrayObject::Binder>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QOpenGLVertexArrayObject::Binder::rebind()", __this_nativeId)
        __qt_this->rebind();
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QOpenGLVertexArrayObject::Binder::release()
extern "C" JNIEXPORT void JNICALL Java_io_qt_opengl_QOpenGLVertexArrayObject_00024Binder_release_1native__J
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
        QOpenGLVertexArrayObject::Binder *__qt_this = QtJambiAPI::objectFromNativeId<QOpenGLVertexArrayObject::Binder>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QOpenGLVertexArrayObject::Binder::release()", __this_nativeId)
        __qt_this->release();
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// emitting (writeJavaLangObjectOverrideFunctions)

void initialize_meta_info_QOpenGLVertexArrayObject_Binder(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerObjectTypeInfo<QOpenGLVertexArrayObject::Binder>("QOpenGLVertexArrayObject::Binder", "io/qt/opengl/QOpenGLVertexArrayObject$Binder");
    registerConstructorInfos(typeId, 0, &__qt_destruct_QOpenGLVertexArrayObject_Binder, {
        ConstructorInfo{&__qt_construct_QOpenGLVertexArrayObject_Binder_QOpenGLVertexArrayObject_ptr, "Lio/qt/opengl/QOpenGLVertexArrayObject;"}
    });
    registerDeleter(typeId, &deleter_QOpenGLVertexArrayObject_Binder);
}
